@@ -20,7 +20,7 @@ from pyiron_base.interfaces.has_hdf import HasHDF
 
 __author__ = "Marvin Poul"
 __copyright__ = (
-    "Copyright 2020, Max-Planck-Institut für Eisenforschung GmbH - "
+    "Copyright 2021, Max-Planck-Institut für Eisenforschung GmbH - "
     "Computational Materials Design (CM) Department"
 )
 __version__ = "1.1"
@@ -39,6 +39,7 @@ _internal_hdf_nodes = [
         "READ_ONLY"
 ]
 
+
 def _normalize(key):
     if isinstance(key, str):
         if key.isdecimal():
@@ -51,6 +52,7 @@ def _normalize(key):
 
     return key
 
+
 class DataContainer(MutableMapping, HasGroups, HasHDF):
     """
     Mutable sequence with optional keys.
@@ -287,6 +289,9 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
         key = _normalize(key)
 
         if isinstance(key, tuple):
+            if key[0] == "..." and len(key) > 1:
+                res = self.search(key[1], False)
+                return res if (len(key) == 2) else res[key[2:]]
             return self[key[0]][key[1:]]
 
         elif isinstance(key, int):
@@ -324,6 +329,10 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
         key = _normalize(key)
 
         if isinstance(key, tuple):
+            if key[0] == "..." and len(key) > 1:
+                res = self._search_parent(key[1], False)
+                res[key[1:]] = val
+                return
             if key[0] not in self.keys():
                 self[key[0]] = type(self)()
             self[key[0]][key[1:]] = val
@@ -353,6 +362,10 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
         key = _normalize(key)
 
         if isinstance(key, tuple):
+            if key[0] == "..." and len(key) > 1:
+                res = self._search_parent(key[1], False)
+                del res[key[1:]]
+                return
             del self[key[0]][key[1:]]
         elif isinstance(key, (str, int)):
             if isinstance(key, str):
@@ -510,6 +523,78 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
         else:
             return super().get(key, default=default)
 
+    def search(self, key, stop_on_first_hit=True):
+        """
+        Search for ``key`` in the Container hierarchy.
+
+        This should be used if there is only one such item in the hierarchy.
+
+        If stop_on_first_hit is True the first item found is taken.
+        Otherwise, a ValueError is raised if the key appears multiple times.
+
+        Args:
+            key (str):                the key to look for
+            stop_on_first_hit (bool): whether to stop on the first hit
+
+        Raise:
+            TypeError:  if key is not str
+            KeyError:   if key is not found
+            ValueError: if stop_on_first_hit is False and key is found twice
+
+        Returns:
+            object: element at ``key``
+        """
+
+        if not isinstance(key, str):
+            raise TypeError("Cannot search for non-string key.")
+
+        parent = self._search_parent(key, stop_on_first_hit)
+        if parent is None:
+            raise KeyError("Could not find any element '" + key + "' in tree.")
+
+        return parent[key]
+
+    def _search_parent(self, key, stop_on_first_hit=True):
+        """
+        Search for container in hierarchy which has ``key``
+
+        This should be used if there is only one such item in the hierarchy.
+        If stop_on_first_hit is True the first item found is taken.
+        Otherwise, a ValueError is raised if the key appears multiple times.
+
+        Args:
+            key (str):                the key to look for
+            stop_on_first_hit (bool): what to do if key is found
+                                      True  => return
+                                      False => continue to check that it is
+                                               the only hit
+        Raise:
+            ValueError: if key is found twice and stop_on_first_hit is False
+
+        Returns:
+            DataContainer: container that has ``key``
+        """
+        # search within current level
+        if key in self:
+            if stop_on_first_hit:
+                return self
+            else:
+                first_hit = self
+        else:
+            first_hit = None
+
+        # descend into subgroups
+        for it in self.groups():
+            hit = self[it]._search_parent(key, stop_on_first_hit)
+            if isinstance(hit, DataContainer):
+                if stop_on_first_hit:
+                    return hit
+                else:
+                    if isinstance(first_hit, DataContainer):
+                        raise ValueError("'" + key + "' exists more than once!")
+                first_hit = hit
+        return first_hit
+
     def update(self, init, wrap=False, **kwargs):
         """
         Add all elements or key-value pairs from init to this container.  If wrap is
@@ -736,7 +821,6 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
             for g in hdf.list_groups():
                 items.append( (*normalize_key(g), hdf[g].to_object() if not self._lazy else HDFStub(hdf, g)) )
 
-
             for _, k, v in sorted(items, key=lambda x: x[0]):
                 self[k] = v
 
@@ -803,4 +887,5 @@ class DataContainer(MutableMapping, HasGroups, HasHDF):
         # that the DataContainer is registered
         HDFStub.register(cls, lambda h, g: h[g].to_object(lazy=True))
 
+
 HDFStub.register(DataContainer, lambda h, g: h[g].to_object(lazy=True))
