@@ -13,6 +13,7 @@ import posixpath
 import multiprocessing
 from pyiron_base.job.wrapper import JobWrapper
 from pyiron_base.settings.generic import Settings
+from pyiron_base.database.manager import DatabaseManager
 from pyiron_base.job.executable import Executable
 from pyiron_base.job.jobstatus import JobStatus
 from pyiron_base.job.core import JobCore
@@ -39,6 +40,7 @@ __status__ = "production"
 __date__ = "Sep 1, 2017"
 
 s = Settings()
+dbm = DatabaseManager()
 
 intercepted_signals = [
     signal.SIGINT,
@@ -53,7 +55,8 @@ class GenericJob(JobCore):
     all specific Hamiltonians are derived. Therefore it should contain the properties/routines common to all jobs.
     The functions in this module should be as generic as possible.
 
-    Sub classes that need to add special behavior after :method:`.copy_to()` can override :method:`._after_generic_copy_to()`.
+    Sub classes that need to add special behavior after :method:`.copy_to()` can override
+    :method:`._after_generic_copy_to()`.
 
     Args:
         project (ProjectHDFio): ProjectHDFio instance which points to the HDF5 file the job is stored in
@@ -644,7 +647,7 @@ class GenericJob(JobCore):
             run_again (bool): Same as delete_existing_job (deprecated)
         """
         if run_again:
-            delete_existing_job=True
+            delete_existing_job = True
         try:
             self._logger.info(
                 "run {}, status: {}".format(self.job_info_str, self.status)
@@ -749,7 +752,7 @@ class GenericJob(JobCore):
                 with open(error_file, "w") as f:
                     f.write(e.output)
                 if self.server.run_mode.non_modal:
-                    s.close_connection()
+                    dbm.close_connection()
                 raise RuntimeError("Job aborted")
             else:
                 job_crashed = True
@@ -773,7 +776,7 @@ class GenericJob(JobCore):
             transfer_back=True,
             delete_remote=s.queue_adapter.ssh_delete_file_on_remote
         )
-        if s.database_is_disabled:
+        if dbm.database_is_disabled:
             self.project.db.update()
         else:
             ft = FileTable(project=self.project_hdf5.path + "_hdf5/")
@@ -869,7 +872,7 @@ class GenericJob(JobCore):
         The run if non modal function is called by run to execute the simulation in the background. For this we use
         multiprocessing.Process()
         """
-        if not s.using_local_database:
+        if not dbm.using_local_database:
             p = multiprocessing.Process(
                 target=multiprocess_wrapper,
                 args=(self.job_id, self.project_hdf5.working_directory, False, None),
@@ -927,7 +930,7 @@ class GenericJob(JobCore):
                 file=self.project_hdf5.file_name,
                 transfer_back=False
             )
-        elif s.database_is_disabled:
+        elif dbm.database_is_disabled:
             command = "python -m pyiron_base.cli wrapper -p " \
                       + self.working_directory \
                       + " -f " + self.project_hdf5.file_name + self.project_hdf5.h5_path
@@ -1036,7 +1039,7 @@ class GenericJob(JobCore):
         job._init_child_job(self)
         return job
 
-    def update_master(self):
+    def update_master(self, force_update=False):
         """
         After a job is finished it checks whether it is linked to any metajob - meaning the master ID is pointing to
         this jobs job ID. If this is the case and the master job is in status suspended - the child wakes up the master
@@ -1044,20 +1047,25 @@ class GenericJob(JobCore):
         status refresh. If another child calls update_master, while the master is in refresh the status of the master is
         set to busy and if the master is in status busy at the end of the update_master process another update is
         triggered.
+
+        Args:
+            force_update (bool): Whether to check run mode for updating master
         """
         master_id = self.master_id
         project = self.project
         self._logger.info("update master: {} {} {}".format(master_id, self.get_job_id(), self.server.run_mode))
-        if (
-            master_id is not None
-            and not self.server.run_mode.thread
-            and not self.server.run_mode.modal
-            and not self.server.run_mode.interactive
-        ):
-            self._reload_update_master(
-                project=project,
-                master_id=master_id
+        if master_id is not None and (
+            force_update or
+            not (
+                self.server.run_mode.thread
+                or self.server.run_mode.modal
+                or self.server.run_mode.interactive
             )
+        ):
+                self._reload_update_master(
+                    project=project,
+                    master_id=master_id
+                )
 
     def job_file_name(self, file_name, cwd=None):
         """
@@ -1445,7 +1453,7 @@ class GenericJob(JobCore):
             run_again (bool): Same as delete_existing_job (deprecated)
         """
         if run_again:
-            delete_existing_job=True
+            delete_existing_job = True
         if delete_existing_job:
             parent_id = self.parent_id
             self.parent_id = None
@@ -1633,7 +1641,7 @@ class GenericError(object):
         for message in [self.print_message(), self.print_queue()]:
             if message is True:
                 all_messages += message
-        if len(all_messages)==0:
+        if len(all_messages) == 0:
             all_messages = 'There is no error/warning'
         return all_messages
 
